@@ -1,7 +1,7 @@
 testinfra_hosts = ['ansible://bind-host']
 
 
-def test_openvpnclient(host):
+def test_openvpnclient_installed(host):
     cmd = host.run("systemctl list-units --all openvpn*")
     print(cmd.stdout)
     print(cmd.stderr)
