@@ -49,6 +49,33 @@ def test_hosts_ensure(tmpdir):
     assert h.hosts[host] == {}
 
 
+@pytest.mark.parametrize('group_name', ('all', 'live', 'unexpected'))
+def test_hosts_group_name(tmpdir, group_name):
+    config_dir = str(tmpdir)
+    h = Hosts(config_dir)
+    assert not h.hosts
+
+    h.save()  # create '{config_dir}/inventory' directory
+
+    f = f'{config_dir}/inventory/hosts.yml'
+    open(f, 'w').write(yaml.dump({
+        group_name: {
+            'hosts': {
+                'some-host': {
+                    'ansible_host': '1.2.3.4',
+                }
+            }
+        }
+    }))
+    try:
+        h.load()
+    except Exception:
+        assert group_name == 'unexpected'
+    else:
+        assert group_name in ('live', 'all')
+        assert 'some-host' in h.hosts
+
+
 #
 # DotEnough
 #
