@@ -383,7 +383,7 @@ def test_info_service(tmpdir, service, expected):
     config_dir = prepare_config_dir(enough_domain, tmpdir)
     f = f'{config_dir}/inventory/hosts.yml'
     open(f, 'w').write(yaml.dump({
-        'all': {
+        'live': {
             'hosts': {
                 'some-host': {
                     'ansible_host': '1.2.3.4',
@@ -411,7 +411,7 @@ def test_info_internal(tmpdir):
     config_dir = prepare_config_dir(enough_domain, tmpdir)
     f = f'{config_dir}/inventory/hosts.yml'
     open(f, 'w').write(yaml.dump({
-        'all': {
+        'live': {
             'hosts': {
                 'some-host': {
                     'ansible_host': '1.2.3.4',
