@@ -3,7 +3,7 @@ import json
 from enough import cmd
 
 
-def test_host_create(capsys, mocker):
+def test_host_create(capsys, mocker, tmp_config_dir):
     # do not tamper with logging streams to avoid
     # ValueError: I/O operation on closed file.
     mocker.patch('cliff.app.App.configure_logging')
@@ -15,7 +15,7 @@ def test_host_create(capsys, mocker):
     assert {'port': j['port'], 'ipv4': j['ip']} == r
 
 
-def test_host_delete(mocker):
+def test_host_delete(mocker, tmp_config_dir):
     # do not tamper with logging streams to avoid
     # ValueError: I/O operation on closed file.
     mocker.patch('cliff.app.App.configure_logging')
